@@ -19,122 +19,6 @@
         <translation>Lineaarinen PCM-äänidata</translation>
     </message>
 </context>
-<context>
-    <name>BbCameraAudioEncoderSettingsControl</name>
-    <message>
-        <source>No compression</source>
-        <translation>Ei pakkausta</translation>
-    </message>
-    <message>
-        <source>AAC compression</source>
-        <translation>AAC-pakkaus</translation>
-    </message>
-    <message>
-        <source>PCM uncompressed</source>
-        <translation>PCM, pakkaamaton</translation>
-    </message>
-</context>
-<context>
-    <name>BbCameraMediaRecorderControl</name>
-    <message>
-        <source>Unable to retrieve mute status</source>
-        <translation>Ei voitu hakea vaimennuksen tilaa</translation>
-    </message>
-    <message>
-        <source>Unable to retrieve audio input volume</source>
-        <translation>Ei voitu hakea äänitulon voimakkuutta</translation>
-    </message>
-    <message>
-        <source>Unable to set mute status</source>
-        <translation>Ei voitu asettaa vaimennuksen tilaa</translation>
-    </message>
-    <message>
-        <source>Unable to set audio input volume</source>
-        <translation>Ei voitu asettaa äänitulon voimakkuutta</translation>
-    </message>
-</context>
-<context>
-    <name>BbCameraSession</name>
-    <message>
-        <source>Camera provides image in unsupported format</source>
-        <translation>Kameralta saatu kuva ei ole tuetussa muodossa</translation>
-    </message>
-    <message>
-        <source>Could not load JPEG data from frame</source>
-        <translation>JPEG-dataa ei saatu ladattua puskurista</translation>
-    </message>
-    <message>
-        <source>Camera not ready</source>
-        <translation>Kamera ei ole valmis</translation>
-    </message>
-    <message>
-        <source>Unable to apply video settings</source>
-        <translation>Videoasetusten asettaminen epäonnistui</translation>
-    </message>
-    <message>
-        <source>Could not open destination file:
-%1</source>
-        <translation>Virhe avattaessa kohdetiedostoa:
-%1</translation>
-    </message>
-    <message>
-        <source>Unable to open camera</source>
-        <translation>Ei voitu avata kameraa</translation>
-    </message>
-    <message>
-        <source>Unable to retrieve native camera orientation</source>
-        <translation>Ei voitu hakea kameran asennusasentoa</translation>
-    </message>
-    <message>
-        <source>Unable to close camera</source>
-        <translation>Ei voitu sulkea kameraa</translation>
-    </message>
-    <message>
-        <source>Unable to start video recording</source>
-        <translation>Ei voitu aloittaa videon tallennusta</translation>
-    </message>
-    <message>
-        <source>Unable to stop video recording</source>
-        <translation>Ei voitu lopettaa videon tallennusta</translation>
-    </message>
-</context>
-<context>
-    <name>BbCameraVideoEncoderSettingsControl</name>
-    <message>
-        <source>No compression</source>
-        <translation>Ei pakkausta</translation>
-    </message>
-    <message>
-        <source>AVC1 compression</source>
-        <translation>AVC1-pakkaus</translation>
-    </message>
-    <message>
-        <source>H264 compression</source>
-        <translation>H264-pakkaus</translation>
-    </message>
-</context>
-<context>
-    <name>BbImageEncoderControl</name>
-    <message>
-        <source>JPEG image</source>
-        <translation>JPEG-kuva</translation>
-    </message>
-</context>
-<context>
-    <name>BbVideoDeviceSelectorControl</name>
-    <message>
-        <source>Front Camera</source>
-        <translation>Etukamera</translation>
-    </message>
-    <message>
-        <source>Rear Camera</source>
-        <translation>Takakamera</translation>
-    </message>
-    <message>
-        <source>Desktop Camera</source>
-        <translation>Työpöytäkamera</translation>
-    </message>
-</context>
 <context>
     <name>CameraBinImageCapture</name>
     <message>
@@ -173,6 +57,26 @@
 </context>
 <context>
     <name>DSCameraSession</name>
+    <message>
+        <source>Failed to configure preview format</source>
+        <translation>Esikatselun kuvamuodon asettaminen epäonnistui</translation>
+    </message>
+    <message>
+        <source>Failed to connect graph</source>
+        <translation>Graafin yhdistäminen epäonnistui</translation>
+    </message>
+    <message>
+        <source>Failed to get stream control</source>
+        <translation>Virran hallinnan saanti epäonnistui</translation>
+    </message>
+    <message>
+        <source>Failed to start</source>
+        <translation>Käynnistäminen epäonnistui</translation>
+    </message>
+    <message>
+        <source>Failed to stop</source>
+        <translation>Pysäyttäminen epäonnistui</translation>
+    </message>
     <message>
         <source>Camera not ready for capture</source>
         <translation>Kamera ei ole valmiina kaappaamaan</translation>
@@ -181,6 +85,26 @@
         <source>Could not save image to file.</source>
         <translation>Kuvan tallentaminen tiedostoon epäonnistui.</translation>
     </message>
+    <message>
+        <source>Failed to create filter graph</source>
+        <translation>Suodatingraafin luonti epäonnistui</translation>
+    </message>
+    <message>
+        <source>Failed to create graph builder</source>
+        <translation>Graafin rakentajan luonti epäonnistui</translation>
+    </message>
+    <message>
+        <source>Failed to connect capture graph and filter graph</source>
+        <translation>Kaappaus- ja suodatingraafien yhdistäminen epäonnistui</translation>
+    </message>
+    <message>
+        <source>No capture device found</source>
+        <translation>Kaappauslaitetta ei löydy</translation>
+    </message>
+    <message>
+        <source>Failed to create null renderer</source>
+        <translation>Tyhjän piirtäjän luonti epäonnistui</translation>
+    </message>
 </context>
 <context>
     <name>MFPlayerSession</name>
@@ -394,13 +318,6 @@
         <translation>Ei voida toistaa virtaa jonka tyyppi on: &lt;tuntematon&gt;</translation>
     </message>
 </context>
-<context>
-    <name>QGstreamerAudioEncode</name>
-    <message>
-        <source>Raw PCM audio</source>
-        <translation>Raaka PCM-audio</translation>
-    </message>
-</context>
 <context>
     <name>QGstreamerAudioInputSelector</name>
     <message>
@@ -457,10 +374,6 @@
         <source>UDP source timeout</source>
         <translation>UDP-lähteen aikakatkaisu</translation>
     </message>
-    <message>
-        <source>Media is loaded as a playlist</source>
-        <translation>Media on ladattu soittolistana</translation>
-    </message>
 </context>
 <context>
     <name>QGstreamerRecorderControl</name>
@@ -555,6 +468,10 @@
         <source>invalid line in playlist file</source>
         <translation>virheellinen rivi soittolistatiedostossa</translation>
     </message>
+    <message>
+        <source>Invalid stream</source>
+        <translation>Virheellinen virta</translation>
+    </message>
     <message>
         <source>Empty file provided</source>
         <translation>Saatiin tyhjä tiedosto</translation>
